#[repr(i32)]pub enum PositionStatusProto {
Unknown = 0,
Hypothetical = 1,
Intended = 2,
Executed = 3,
}Variants
Unknown = 0
Hypothetical = 1
Hypothetical status means a transaction, tax lot or position that may never occur. This can be used to understand how potential actions could impact a portfolio
Intended = 2
Intended status means a transaction, tax lot or position that is expected to occur if nothing changes. For example a fixed income bond that is expected to pay a coupon, or a security that is expected to mature in a specific point in the future
Executed = 3
Executed status means a transaction, tax lot or position that is the result of a legally binding transaction
Implementations
Sourceimpl PositionStatusProto
impl PositionStatusProto
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.