pub struct QueryTransactionRequestProto {
pub object_class: String,
pub version: String,
pub uu_ids: Vec<UuidProto>,
pub search_transaction_input: Option<PositionFilterProto>,
pub as_of: Option<LocalTimestampProto>,
pub limit: i32,
}Fields
object_class: Stringversion: Stringuu_ids: Vec<UuidProto>The list of UUIds to return
search_transaction_input: Option<PositionFilterProto>A list of position filters that will filter securities that match.
as_of: Option<LocalTimestampProto>The as of date to query the data set
limit: i32Max number of records to return