pub struct QueryTransactionResponseProto {
pub object_class: String,
pub version: String,
pub create_transaction_request: Option<QueryTransactionRequestProto>,
pub transaction_response: Vec<TransactionProto>,
pub errors_or_warnings: Option<SummaryProto>,
}Fields
object_class: Stringversion: Stringcreate_transaction_request: Option<QueryTransactionRequestProto>transaction_response: Vec<TransactionProto>errors_or_warnings: Option<SummaryProto>If no errors or warnings in the response then the request was processed successfully without any contingencies.