#[repr(i32)]pub enum EntityTypeProto {
UnknownEntity = 0,
Security = 1,
Portfolio = 2,
Transaction = 3,
Price = 4,
Position = 5,
}Expand description
The type of entity being deleted or affected by a cascade deletion.
Variants
Implementations
Sourceimpl EntityTypeProto
impl EntityTypeProto
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.